# Import the random module to generate random numbers
import random

# --- Game Setup ---
# Generate a random integer between 1 and 20 (inclusive)
secret_number = random.randint(1, 20)
max_guesses = 6 # Define the maximum number of guesses allowed

# --- Introduction ---
print('--- Guess the Number Game ---')
print(f'I am thinking of a number between 1 and 20.')
print(f'You have {max_guesses} tries to guess it.')
print('-----------------------------')

# --- Guessing Loop ---
# Use a variable to store the player's guess outside the loop initially
guess = None

# Loop for the allowed number of guesses
# range(1, max_guesses + 1) ensures the loop runs exactly max_guesses times (e.g., 1 to 7 for 6 guesses)
for guesses_taken in range(1, max_guesses + 1):
    print(f'Guess #{guesses_taken}:')

    # Get player input
    try:
        # Use input() to get text from the player
        # Use int() to convert the text into a whole number (integer)
        guess_input = input()
        guess = int(guess_input)

        # --- Compare the Guess ---
        if guess < secret_number:
            print('Your guess is too low.')
        elif guess > secret_number:
            print('Your guess is too high.')
        else:
            # The guess is correct!
            break # Exit the loop immediately

    except ValueError:
        # Handle cases where the input is not a valid number
        print('Invalid input. Please enter a whole number.')

    # Check if it was the last guess and still incorrect
    if guesses_taken == max_guesses and guess != secret_number:
        # This block is reached only if the loop is about to end naturally
        # and the last guess wasn't the secret number.
        pass # No need to do anything here, the final check after the loop handles it.

# --- Game End ---
# This code runs after the loop finishes (either by 'break' or after all guesses)

if guess == secret_number:
    # Player guessed correctly
    print('-----------------------------')
    print(f'Good job! You guessed my number in {guesses_taken} guesses!')
    print('-----------------------------')
else:
    # Player ran out of guesses
    print('-----------------------------')
    print(f'Nope. You ran out of guesses.')
    print(f'The number I was thinking of was {secret_number}.')
    print('-----------------------------')

# End of the game



